@@ -1,15 +1,16 @@
+use chrono::Local;
 use thrift::Error;
 
 use iotdb::common::{Compressor, DataType, Encoding};
-use iotdb::{Config, Session};
+use iotdb::{ConfigBuilder, Session};
 
 fn main() -> Result<(), Error> {
-    let config = Config::new()
+    let config = ConfigBuilder::new()
         .endpoint("127.0.0.1", "6667")
         .user("root")
         .password("root")
-        .zone_id("UTC+8")
-        .debug(true)
+        .time_zone("UTC+8")
+        // .debug(true)
         .build();
 
     // open session
@@ -31,13 +32,34 @@ fn main() -> Result<(), Error> {
         Compressor::default(),
     )?;
 
-    session.sql("INSERT INTO root.ln.wf01.wt01(timestamp,status) values(100,true)")?;
-    session.sql("INSERT INTO root.ln.wf01.wt01(timestamp,status) values(200,false)")?;
+    let now = Local::now().timestamp_millis();
     session.sql(
-        "INSERT INTO root.ln.wf01.wt01(timestamp,status,temperature) values(300,false,18.36)",
+        format!(
+            "INSERT INTO root.ln.wf01.wt01(timestamp,status) values({},true)",
+            now
+        )
+        .as_str(),
     )?;
     session.sql(
-        "INSERT INTO root.ln.wf01.wt01(timestamp,status,temperature) values(400,true,32.23)",
+        format!(
+            "INSERT INTO root.ln.wf01.wt01(timestamp,status) values({},false)",
+            now + 1000
+        )
+        .as_str(),
+    )?;
+    session.sql(
+        format!(
+            "INSERT INTO root.ln.wf01.wt01(timestamp,status,temperature) values({},false,18.36)",
+            now + 2000
+        )
+        .as_str(),
+    )?;
+    session.sql(
+        format!(
+            "INSERT INTO root.ln.wf01.wt01(timestamp,status,temperature) values({},true,32.23)",
+            now + 3000
+        )
+        .as_str(),
     )?;
     session.sql("select * from root.ln")?.show();
 
