@@ -7,7 +7,7 @@
 //! [![Rust Build](https://img.shields.io/github/workflow/status/francis-du/iotdb-rs/cargo-test?label=build&style=flat-square)](https://github.com/francis-du/iotdb-rs/actions?query=workflow%3Acargo-test)
 //! [![Crates Publish](https://img.shields.io/github/workflow/status/francis-du/iotdb-rs/cargo-publish?label=publish&style=flat-square)](https://github.com/francis-du/iotdb-rs/actions?query=workflow%3Acargo-publish)
 //!
-//! (WIP) Apache IotDB Client written in Rust
+//! Apache IotDB Client written in Rust
 //!
 //! # Overview
 //!
@@ -22,27 +22,28 @@
 //!
 //! ```toml
 //! [dependencies]
-//! iotdb = "0.0.5"
+//! iotdb = "0.0.6"
 //! ```
 //!
 //! # Example
 //!
 //! ```rust
+//! use chrono::Local;
 //! use thrift::Error;
 //!
 //! use iotdb::common::{Compressor, DataType, Encoding};
-//! use iotdb::{Config, Session};
+//! use iotdb::{ConfigBuilder, Session};
 //!
 //! fn main() -> Result<(), Error> {
-//!     let config = Config::new()
+//!  let config = ConfigBuilder::new()
 //!         .endpoint("127.0.0.1", "6667")
 //!         .user("root")
 //!         .password("root")
 //!         .zone_id("UTC+8")
-//!         // .debug(true)
+//!         .debug(true)
 //!         .build();
 //!
-//!     // open session
+//!      // open session
 //!     let mut session = Session::new(config).open()?;
 //!     println!("time_zone: {}", session.time_zone()?);
 //!     session.delete_storage_group("root.ln")?;
@@ -61,27 +62,51 @@
 //!         Compressor::default(),
 //!     )?;
 //!
-//!     session.sql("INSERT INTO root.ln.wf01.wt01(timestamp,status) values(100,true)")?;
-//!     session.sql("INSERT INTO root.ln.wf01.wt01(timestamp,status) values(200,false)")?;
+//!     let now = Local::now().timestamp();
 //!     session.sql(
-//!         "INSERT INTO root.ln.wf01.wt01(timestamp,status,temperature) values(300,false,18.36)",
+//!         format!(
+//!             "INSERT INTO root.ln.wf01.wt01(timestamp,status) values({},true)",
+//!             now
+//!         )
+//!         .as_str(),
 //!     )?;
 //!     session.sql(
-//!         "INSERT INTO root.ln.wf01.wt01(timestamp,status,temperature) values(400,true,32.23)",
+//!         format!(
+//!             "INSERT INTO root.ln.wf01.wt01(timestamp,status) values({},false)",
+//!             now + 1000
+//!         )
+//!         .as_str(),
 //!     )?;
-//!     session.sql("select * from root.ln")?.show();
+//!     session.sql(
+//!         format!(
+//!             "INSERT INTO root.ln.wf01.wt01(timestamp,status,temperature) values({},false,18.36)",
+//!             now + 2000
+//!         )
+//!         .as_str(),
+//!     )?;
+//!     session.sql(
+//!         format!(
+//!             "INSERT INTO root.ln.wf01.wt01(timestamp,status,temperature) values({},true,32.23)",
+//!             now + 3000
+//!         )
+//!         .as_str(),
+//!     )?;
+//!    session.sql("select * from root.ln")?.show();
+//!    session.close()?;
 //!
-//!     session.close()?;
-//!
-//!     Ok(())
+//!   Ok(())
 //! }
 //! ```
 pub mod common;
 pub mod dataset;
 pub mod rpc;
 
+pub use chrono;
 pub use thrift;
 
+#[macro_use]
+extern crate prettytable;
+
 use crate::common::{Compressor, DataType, Encoding, Logger};
 use crate::dataset::DataSet;
 use crate::rpc::{
@@ -92,10 +117,9 @@ use crate::rpc::{
     TSStatus, TTSIServiceSyncClient,
 };
 use chrono::{Local, Utc};
-use log::{debug, error};
-use mimalloc::MiMalloc;
+use log::{debug, error, info};
+use simplelog::*;
 use std::collections::BTreeMap;
-use std::env;
 use std::net::TcpStream;
 use std::str::FromStr;
 use thrift::protocol::{
@@ -103,18 +127,11 @@ use thrift::protocol::{
     TInputProtocol, TOutputProtocol,
 };
 use thrift::transport::{TFramedReadTransport, TFramedWriteTransport, TIoChannel, TTcpChannel};
-use thrift::{ApplicationErrorKind, Error, ProtocolErrorKind};
-
-#[macro_use]
-extern crate prettytable;
-
-#[global_allocator]
-static GLOBAL: MiMalloc = MiMalloc;
+use thrift::{ApplicationErrorKind, Error as ThriftError, ProtocolErrorKind};
 
 type ClientType = TSIServiceSyncClient<Box<dyn TInputProtocol>, Box<dyn TOutputProtocol>>;
 
 const SUCCESS_CODE: i32 = 200;
-const LOG_LEVER_KEY: &str = "IOTDB_LOG_LEVER";
 
 #[derive(Clone, Debug)]
 pub struct Endpoint {
@@ -164,11 +181,11 @@ impl ToString for Endpoint {
 pub struct Config {
     pub user: String,
     pub password: String,
-    pub zone_id: String,
+    pub time_zone: String,
     pub timeout: i64,
     pub fetch_size: i32,
     pub endpoint: Endpoint,
-    pub log_level: String,
+    pub log_level: LevelFilter,
     pub rpc_compaction: bool,
     pub protocol_version: TSProtocolVersion,
     pub enable_redirect_query: bool,
@@ -182,9 +199,9 @@ impl Default for Config {
             user: "root".to_string(),
             password: "root".to_string(),
             timeout: 3000,
-            zone_id: format!("{}{}", Utc::now().offset(), Local::now().offset()),
+            time_zone: format!("{}{}", Utc::now().offset(), Local::now().offset()),
             fetch_size: 1024,
-            log_level: env::var(LOG_LEVER_KEY).unwrap_or_else(|_| "info".to_string()),
+            log_level: LevelFilter::Info,
             rpc_compaction: false,
             protocol_version: TSProtocolVersion::IOTDB_SERVICE_PROTOCOL_V3,
             enable_redirect_query: false,
@@ -193,82 +210,88 @@ impl Default for Config {
     }
 }
 
-impl Config {
+pub struct ConfigBuilder(Config);
+
+impl Default for ConfigBuilder {
+    fn default() -> Self {
+        Self::new()
+    }
+}
+
+impl ConfigBuilder {
     pub fn new() -> Self {
-        let default = Config::default();
-        debug!("{:?}", default);
-        default
+        ConfigBuilder(Config::default())
     }
 
     pub fn endpoint(&mut self, host: &str, port: &str) -> &mut Self {
-        self.endpoint = Endpoint::new(host, port);
+        self.0.endpoint = Endpoint::new(host, port);
         self
     }
 
     pub fn user(&mut self, user: &str) -> &mut Self {
-        self.user = user.to_string();
+        self.0.user = user.to_string();
         self
     }
 
     pub fn password(&mut self, password: &str) -> &mut Self {
-        self.password = password.to_string();
+        self.0.password = password.to_string();
         self
     }
 
     pub fn timeout(&mut self, timeout: i64) -> &mut Self {
-        self.timeout = timeout;
+        self.0.timeout = timeout;
         self
     }
 
-    pub fn zone_id(&mut self, zone_id: &str) -> &mut Self {
-        self.zone_id = zone_id.to_uppercase();
+    pub fn time_zone(&mut self, time_zone: &str) -> &mut Self {
+        self.0.time_zone = time_zone.to_uppercase();
         self
     }
 
     pub fn fetch_size(&mut self, fetch_size: i32) -> &mut Self {
-        self.fetch_size = fetch_size;
+        self.0.fetch_size = fetch_size;
         self
     }
 
-    pub fn log_level(&mut self, level: &str) -> &mut Self {
-        self.log_level = level.to_string();
+    pub fn log_level(&mut self, level: LevelFilter) -> &mut Self {
+        self.0.log_level = level;
         self
     }
 
     pub fn debug(&mut self, debug: bool) -> &mut Self {
         if debug {
-            self.log_level = "debug".to_string();
+            self.0.log_level = LevelFilter::Debug
         }
         self
     }
 
     pub fn enable_rpc_compaction(&mut self) -> &mut Self {
-        self.rpc_compaction = true;
+        self.0.rpc_compaction = true;
         self
     }
 
-    pub fn protocol_version(&mut self, protocol_version: TSProtocolVersion) -> &mut Self {
-        self.protocol_version = protocol_version;
+    pub fn set_protocol_version(&mut self, protocol_version: TSProtocolVersion) -> &mut Self {
+        self.0.protocol_version = protocol_version;
         self
     }
 
     pub fn enable_redirect_query(&mut self, enable_redirect_query: bool) -> &mut Self {
-        self.enable_redirect_query = enable_redirect_query;
+        self.0.enable_redirect_query = enable_redirect_query;
         self
     }
 
-    pub fn set(&mut self, key: &str, value: &str) -> &mut Self {
-        self.config_map.insert(key.to_string(), value.to_string());
+    pub fn set_config(&mut self, key: &str, value: &str) -> &mut Self {
+        self.0.config_map.insert(key.to_string(), value.to_string());
         self
     }
 
-    pub fn set_map(&mut self, map: &mut BTreeMap<String, String>) -> &mut Self {
-        self.config_map.append(map);
+    pub fn set_config_map(&mut self, map: &mut BTreeMap<String, String>) -> &mut Self {
+        self.0.config_map.append(map);
         self
     }
 
-    pub fn build(&self) -> Self {
-        self.clone()
+    pub fn build(&self) -> Config {
+        self.0.clone()
     }
 }
 
@@ -282,25 +305,14 @@ pub struct Session {
 
 impl Session {
     pub fn new(config: Config) -> Session {
-        Logger::new(config.log_level.as_str(), None).init().unwrap();
-        debug!("{:?}", &config);
+        Logger::init(config.log_level);
+        debug!("{:#?}", &config);
+
+        let stream = TcpStream::connect(config.endpoint.to_string()).unwrap_or_else(|error| {
+            panic!("{:?}, reason: {:?}", config.endpoint, error.to_string())
+        });
+        debug!("TcpStream connect to {:?}", config.endpoint);
 
-        let stream: TcpStream = match TcpStream::connect(config.endpoint.to_string()) {
-            Ok(tcp_stream) => {
-                debug!("TcpStream connect to {:?}", config.endpoint);
-                tcp_stream
-            }
-            Err(error) => {
-                error!(
-                    "TcpStream connect to {:?} failed, reason: {}",
-                    config.endpoint, error
-                );
-                panic!(
-                    "TcpStream connect to {:?} failed, reason: {}",
-                    config.endpoint, error
-                );
-            }
-        };
         let channel = TTcpChannel::with_stream(stream);
         let (channel_in, channel_out) = channel.split().unwrap();
         let (transport_in, transport_out) = (
@@ -329,10 +341,10 @@ impl Session {
     }
 
     // Open Session
-    pub fn open(mut self) -> Result<Session, Error> {
+    pub fn open(mut self) -> Result<Session, ThriftError> {
         let open_req = TSOpenSessionReq::new(
             self.config.protocol_version,
-            self.config.zone_id.clone(),
+            self.config.time_zone.clone(),
             self.config.user.clone(),
             self.config.password.clone(),
             self.config.config_map.clone(),
@@ -389,7 +401,7 @@ impl Session {
     }
 
     // Close Session
-    pub fn close(&mut self) -> Result<(), Error> {
+    pub fn close(&mut self) -> Result<(), ThriftError> {
         if self.is_close {
             Ok(())
         } else {
@@ -418,7 +430,7 @@ impl Session {
     }
 
     /// Set a storage group
-    pub fn set_storage_group(&mut self, storage_group: &str) -> Result<(), Error> {
+    pub fn set_storage_group(&mut self, storage_group: &str) -> Result<(), ThriftError> {
         match self
             .client
             .set_storage_group(self.session_id, storage_group.to_string())
@@ -444,13 +456,16 @@ impl Session {
     }
 
     /// Delete a storage group.
-    pub fn delete_storage_group(&mut self, storage_group: &str) -> Result<(), Error> {
+    pub fn delete_storage_group(&mut self, storage_group: &str) -> Result<(), ThriftError> {
         debug!("Delete storage group {:?}", storage_group);
         self.delete_storage_groups(vec![storage_group.to_string()])
     }
 
     /// Delete storage groups.
-    pub fn delete_storage_groups(&mut self, storage_groups: Vec<String>) -> Result<(), Error> {
+    pub fn delete_storage_groups(
+        &mut self,
+        storage_groups: Vec<String>,
+    ) -> Result<(), ThriftError> {
         match self
             .client
             .delete_storage_groups(self.session_id, storage_groups.clone())
@@ -482,7 +497,7 @@ impl Session {
         data_type: DataType,
         encoding: Encoding,
         compressor: Compressor,
-    ) -> Result<(), Error> {
+    ) -> Result<(), ThriftError> {
         let req = TSCreateTimeseriesReq::new(
             self.session_id,
             ts_path.to_string(),
@@ -532,7 +547,7 @@ impl Session {
         data_type_vec: Vec<i32>,
         encoding_vec: Vec<i32>,
         compressor_vec: Vec<i32>,
-    ) -> Result<(), Error> {
+    ) -> Result<(), ThriftError> {
         let req = TSCreateMultiTimeseriesReq::new(
             self.session_id,
             ts_path_vec.clone(),
@@ -566,7 +581,7 @@ impl Session {
     }
 
     /// Delete multiple time series
-    pub fn delete_time_series(&mut self, path_vec: Vec<String>) -> Result<(), Error> {
+    pub fn delete_time_series(&mut self, path_vec: Vec<String>) -> Result<(), ThriftError> {
         match self
             .client
             .delete_timeseries(self.session_id, path_vec.clone())
@@ -592,7 +607,7 @@ impl Session {
     }
 
     /// Check whether a specific time-series exists
-    pub fn check_time_series_exists(&mut self, path: &str) -> Result<bool, Error> {
+    pub fn check_time_series_exists(&mut self, path: &str) -> Result<bool, ThriftError> {
         let config = self.config.clone();
         let statement = format!("SHOW TIMESERIES {}", path);
         let req = TSExecuteStatementReq::new(
@@ -624,7 +639,11 @@ impl Session {
     }
 
     /// Delete all data <= time in multiple time-series
-    pub fn delete_data(&mut self, path_vec: Vec<String>, timestamp: i64) -> Result<(), Error> {
+    pub fn delete_data(
+        &mut self,
+        path_vec: Vec<String>,
+        timestamp: i64,
+    ) -> Result<(), ThriftError> {
         let req = TSDeleteDataReq::new(self.session_id, path_vec.clone(), 0, timestamp);
         match self.client.delete_data(req) {
             Ok(status) => {
@@ -655,7 +674,7 @@ impl Session {
         measurements_list: Vec<Vec<String>>,
         values_list: Vec<Vec<String>>,
         is_aligned: bool,
-    ) -> Result<(), Error> {
+    ) -> Result<(), ThriftError> {
         let req = TSInsertStringRecordsReq::new(
             self.session_id,
             device_ids.clone(),
@@ -693,7 +712,7 @@ impl Session {
         measurements: Vec<String>,
         values: Vec<u8>,
         is_aligned: bool,
-    ) -> Result<(), Error> {
+    ) -> Result<(), ThriftError> {
         let req = TSInsertRecordReq::new(
             self.session_id,
             device_id.to_string(),
@@ -732,7 +751,7 @@ impl Session {
         measurements: Vec<String>,
         values: Vec<u8>,
         is_aligned: bool,
-    ) -> Result<(), Error> {
+    ) -> Result<(), ThriftError> {
         let req = TSInsertRecordReq::new(
             self.session_id,
             prefix_path.to_string(),
@@ -770,7 +789,7 @@ impl Session {
         measurements_list: Vec<Vec<String>>,
         values_list: Vec<Vec<u8>>,
         is_aligned: bool,
-    ) -> Result<(), Error> {
+    ) -> Result<(), ThriftError> {
         let req = TSInsertRecordsReq::new(
             self.session_id,
             prefix_paths.clone(),
@@ -809,7 +828,7 @@ impl Session {
         measurements_list: Vec<Vec<String>>,
         values_list: Vec<Vec<u8>>,
         is_aligned: bool,
-    ) -> Result<(), Error> {
+    ) -> Result<(), ThriftError> {
         let req = TSInsertRecordsReq::new(
             self.session_id,
             prefix_paths,
@@ -857,7 +876,7 @@ impl Session {
         types: Vec<i32>,
         size: i32,
         is_aligned: bool,
-    ) -> Result<TSStatus, Error> {
+    ) -> Result<TSStatus, ThriftError> {
         let req = TSInsertTabletReq::new(
             self.session_id,
             prefix_path.to_string(),
@@ -883,7 +902,7 @@ impl Session {
         types_list: Vec<Vec<i32>>,
         size_list: Vec<i32>,
         is_aligned: bool,
-    ) -> Result<TSStatus, Error> {
+    ) -> Result<TSStatus, ThriftError> {
         let req = TSInsertTabletsReq::new(
             self.session_id,
             prefix_paths,
@@ -922,12 +941,12 @@ impl Session {
     /// TODO
     pub fn gen_insert_tablets_req() {}
 
-    pub fn sql(&mut self, sql: &str) -> Result<DataSet, Error> {
+    pub fn sql(&mut self, sql: &str) -> Result<DataSet, ThriftError> {
         self.exec(sql)
     }
 
     /// execute query sql statement and return a DataSet
-    fn exec(&mut self, statement: &str) -> Result<DataSet, Error> {
+    fn exec(&mut self, statement: &str) -> Result<DataSet, ThriftError> {
         debug!("Exec statement \"{}\"", statement);
         let req = TSExecuteStatementReq::new(
             self.session_id,
@@ -970,13 +989,12 @@ impl Session {
 
     /// execute batch statement and return a DataSets
     pub fn exec_batch(&mut self, statements: Vec<String>) {
-        let req = TSExecuteBatchStatementReq::new(self.session_id, statements.clone());
+        let req = TSExecuteBatchStatementReq::new(self.session_id, statements);
         match self.client.execute_batch_statement(req) {
             Ok(status) => {
-                if !self.is_success(&status) {
-                    debug!(
-                        "Execute statements {:?}, message: {:?}",
-                        statements,
+                if self.is_success(&status) {
+                    info!(
+                        "Execute statements {:?}",
                         status.message.unwrap_or_else(|| "None".to_string())
                     );
                 } else {
@@ -988,7 +1006,7 @@ impl Session {
     }
 
     /// execute query sql statement and return a DataSet
-    pub fn exec_query(&mut self, query: &str) -> Result<DataSet, Error> {
+    pub fn exec_query(&mut self, query: &str) -> Result<DataSet, ThriftError> {
         debug!("Exec query \"{}\"", &query);
         let req = TSExecuteStatementReq::new(
             self.session_id,
@@ -1037,7 +1055,7 @@ impl Session {
     }
 
     /// execute update statement and return a DataSet
-    pub fn exec_update(&mut self, statement: &str) -> Result<DataSet, Error> {
+    pub fn exec_update(&mut self, statement: &str) -> Result<DataSet, ThriftError> {
         let req = TSExecuteStatementReq::new(
             self.session_id,
             statement.to_string(),
@@ -1083,7 +1101,7 @@ impl Session {
         paths: Vec<String>,
         start_time: i64,
         end_time: i64,
-    ) -> Result<DataSet, Error> {
+    ) -> Result<DataSet, ThriftError> {
         let req = TSRawDataQueryReq::new(
             self.session_id,
             paths,
@@ -1117,7 +1135,7 @@ impl Session {
     }
 
     /// Set time zone
-    pub fn set_time_zone(&mut self, time_zone: &str) -> Result<(), Error> {
+    pub fn set_time_zone(&mut self, time_zone: &str) -> Result<(), ThriftError> {
         let req = TSSetTimeZoneReq::new(self.session_id, time_zone.to_string());
         match self.client.set_time_zone(req) {
             Ok(status) => {
@@ -1136,7 +1154,7 @@ impl Session {
     }
 
     /// Get time zone
-    pub fn time_zone(&mut self) -> Result<String, Error> {
+    pub fn time_zone(&mut self) -> Result<String, ThriftError> {
         match self.client.get_time_zone(self.session_id) {
             Ok(resp) => {
                 if resp.status.code == 200 {
@@ -1157,7 +1175,7 @@ impl Session {
 
     /// Cancel operation
     #[allow(dead_code)]
-    fn cancel_operation(&mut self, query_id: i64) -> Result<(), Error> {
+    fn cancel_operation(&mut self, query_id: i64) -> Result<(), ThriftError> {
         let req = TSCancelOperationReq::new(self.session_id, query_id);
         match self.client.cancel_operation(req) {
             Ok(status) => {
